auxiliary file for SID: computes a path matrix efficiently (can probably be made faster) This function takes an adjacency matrix G from a DAG and computes a path matrix for which entry(i,j) being one means that there is a directed path from i to j the diagonal will also be one.
computePathMatrix(G, spars=FALSE)pathMatrix
graph.
boolean indicating whether G is a sparse matrix.
Jonas Peters <[email protected]>
structIntervDist
computePathMatrix2